@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals.html)
 
 Usage::
 
@@ -36,11 +36,8 @@ __all__ = (
     "RelevanceLevelType",
     "SearchContentPaginatorName",
     "SearchSessionsPaginatorName",
-    "ConnectWisdomServiceServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
-    "RegionName",
 )
 
 
@@ -82,7 +79,6 @@ QueryAssistantPaginatorName = Literal["query_assistant"]
 RelevanceLevelType = Literal["HIGH", "LOW", "MEDIUM"]
 SearchContentPaginatorName = Literal["search_content"]
 SearchSessionsPaginatorName = Literal["search_sessions"]
-ConnectWisdomServiceServiceName = Literal["wisdom"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -92,10 +88,12 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -110,6 +108,7 @@ ServiceName = Literal[
     "autoscaling",
     "autoscaling-plans",
     "backup",
+    "backup-gateway",
     "batch",
     "braket",
     "budgets",
@@ -164,6 +163,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -185,6 +185,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -211,6 +212,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -224,6 +226,7 @@ ServiceName = Literal[
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
+    "iottwinmaker",
     "iotwireless",
     "ivs",
     "kafka",
@@ -269,7 +272,9 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -298,11 +303,13 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -312,6 +319,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
@@ -369,20 +377,9 @@ ServiceName = Literal[
     "workmail",
     "workmailmessageflow",
     "workspaces",
+    "workspaces-web",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal[
     "list_assistant_associations",
     "list_assistants",
@@ -392,6 +389,3 @@ PaginatorName = Literal[
     "search_content",
     "search_sessions",
 ]
-RegionName = Literal[
-    "ap-northeast-1", "ap-southeast-2", "eu-central-1", "eu-west-2", "us-east-1", "us-west-2"
-]
